# Figure sizes

ONE_COLUMN_WIDTH = 3.45
TWO_COLUMNS_WIDTH = 7.09
WIDTH = TWO_COLUMNS_WIDTH
HEIGHT = ONE_COLUMN_WIDTH

WIDE_SLIDE_WIDTH = 13
WIDE_SLIDE_HEIGHT = 6.5

# Font sizes

FONTSIZE_SMALL = 5
FONTSIZE = 6
FONTSIZE_BIG = 8

# Marker sizes

MARKERSIZE_SMALL = 5
MARKERSIZE = 10
MARKERSIZE_BIG = 30

# Line sizes

LINEWIDTH = 0.5
LINEWIDTH_THICK = 1
